@@ -385,14 +385,10 @@ class Builder(Update):
     def world_diff(self, builder_path):
         worldfile_snapshot = self.get_world_snapshot_filename(builder_path)
         worldfile = pathJoin(builder_path, "var/lib/portage/world")
-        if self._world_diff(self._chroot_eix_versions(builder_path),
-                            readFile(worldfile_snapshot),
-                            readFile(worldfile),
-                            premess=_("List of worlds differences")):
-            answer = self.askConfirm(
-                _("Would you like to continue?"), "yes")
-            if answer == "no":
-                raise KeyboardInterrupt
+        self._world_diff(self._chroot_eix_versions(builder_path),
+                         readFile(worldfile_snapshot),
+                         readFile(worldfile),
+                         premess=_("List of worlds differences"))
         return True
 
     def _chroot_eix_versions(self, builder_path):
